﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Data;
using System.Globalization;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using DlhSoft.Windows.Controls;
using System.ComponentModel;

namespace DataTreeGridCustomDataBindingSample
{
    public class CustomDataConverter : IValueConverter
    {
        // Retrieve a collection of DataTreeGridItem based on the CustomNodeItem data context.
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            IEnumerable<CustomNodeItem> dataContext = value as IEnumerable<CustomNodeItem>;
            ObservableCollection<DataTreeGridItem> items = new ObservableCollection<DataTreeGridItem>();
            foreach (CustomNodeItem customNodeItem in dataContext)
            {
                DataTreeGridItem item = 
                    new DataTreeGridItem 
                    { 
                        Content = customNodeItem.Name, Indentation = customNodeItem.IndentLevel, 
                        // Set the associated CustomNodeItem object as the Tag value of the DataTreeGridItem.
                        Tag = customNodeItem 
                    };
                items.Add(item);
                item.PropertyChanged += Item_PropertyChanged;
            }
            return items;
        }

        // When a managed property changes on a DataTreeGridItem, propagate the updated value to the appropriate property of the associated CustomNodeItem object.
        private void Item_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            DataTreeGridItem item = sender as DataTreeGridItem;
            CustomNodeItem customNodeItem = item.Tag as CustomNodeItem;
            switch (e.PropertyName)
            {
                case "Content":
                    customNodeItem.Name = item.Content as string;
                    break;
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotSupportedException();
        }
    }
}
